@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2008-2017 by Dominique Dumont.
+# This software is Copyright (c) 2008-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.364';
+$Config::Model::TkUI::VERSION = '1.366';
 use 5.10.1;
 use strict;
 use warnings;
@@ -39,7 +39,7 @@ use Tk::FontDialog;
 use Tk::Pod;
 use Tk::Pod::Text;    # for findpod
 
-use Config::Model 2.095; # Node::get_help_as_text
+use Config::Model 2.114; # Node::gist
 
 use Config::Model::Tk::LeafEditor;
 use Config::Model::Tk::CheckListEditor;
@@ -898,6 +898,10 @@ sub disp_hash {
             $tkt->setmode( $newpath => $eltmode );
         }
 
+        # update the node gist
+        my $gist = $elt_type =~ /node/ ? $elt->fetch_with_id($idx)->fetch_gist : '';
+        $tkt->itemCreate( $newpath, 2, -text => $gist );
+
         my $elt_loc = $node_loc;
         $elt_loc .= ' ' if $elt_loc;
 
